<?php
// Turn off error reporting and display errors
error_reporting(0);
ini_set('display_errors', 0);

// Include the TCPDF library
require_once('tcpdf/tcpdf.php');
include('conn.php');

// Retrieve the registration ID from the URL
$registration_id = isset($_GET['id']) ? $_GET['id'] : '';

if ($registration_id) {
    // Prepare and execute the query to fetch the registration details
    $stmt = $conn->prepare("SELECT * FROM registration WHERE id = :id");
    $stmt->bindParam(':id', $registration_id, PDO::PARAM_INT);
    $stmt->execute();
    $registration = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$registration) {
        echo '<script>alert("No registration found with this ID."); window.location.href = "newregistration.php";</script>';
        exit();
    }
} else {
    echo '<script>alert("Invalid registration ID."); window.location.href = "newregistration.php";</script>';
    exit();
}

// Create new PDF document
$pdf = new TCPDF();
$pdf->AddPage();

// Set document information
$pdf->SetCreator(PDF_CREATOR);
$pdf->SetAuthor('D-WAY GROUP OF SCHOOLS');
$pdf->SetTitle('Invoice');
$pdf->SetSubject('Invoice');

// Set font
$pdf->SetFont('helvetica', '', 12);

// Header
$pdf->SetY(10);
$pdf->SetX(10);
$pdf->Cell(0, 10, 'D-WAY GROUP OF SCHOOLS', 0, 1, 'C');
$pdf->Cell(0, 10, 'Address Line 1', 0, 1, 'C');
$pdf->Cell(0, 10, 'City, State, Zip Code', 0, 1, 'C');
$pdf->Cell(0, 10, 'Phone: +234 7056483766', 0, 1, 'C');
$pdf->Cell(0, 10, 'Email: admissions@d-wayschools.com', 0, 1, 'C');
$pdf->Ln(10);

// To section
$pdf->Cell(0, 10, 'To:', 0, 1, 'L');
$pdf->Cell(0, 10, $registration['name'], 0, 1, 'L');
$pdf->Cell(0, 10, 'Phone: ' . $registration['phone_number'], 0, 1, 'L');
$pdf->Cell(0, 10, 'Email: ' . $registration['email'], 0, 1, 'L');
$pdf->Cell(0, 10, 'Region: ' . $registration['region'], 0, 1, 'L');
$pdf->Cell(0, 10, 'Province: ' . $registration['province'], 0, 1, 'L');
$pdf->Ln(10);

// Invoice details
$created_at = isset($registration['date']) ? date('l, jS F - g:i:s A', strtotime($registration['date'])) : 'Date not available';
$invoice_number = '#AC/' . date('Y') . '/0' . $registration['id'];
$pdf->Cell(0, 10, 'Invoice Number: ' . $invoice_number, 0, 1, 'L');
$pdf->Cell(0, 10, 'Date: ' . $created_at, 0, 1, 'L');
$pdf->Ln(10);

// Invoice table
$pdf->SetFont('helvetica', 'B', 12);
$pdf->Cell(90, 10, 'Description', 1, 0, 'C');
$pdf->Cell(30, 10, 'Quantity', 1, 0, 'C');
$pdf->Cell(60, 10, 'Total Amount', 1, 1, 'C');

$pdf->SetFont('helvetica', '', 12);
$pdf->Cell(90, 10, date("Y") . ' Convention Registration Fee', 1, 0, 'L');
$pdf->Cell(30, 10, ($registration['p1'] + $registration['p2'] + $registration['p3']), 1, 0, 'C');
$pdf->Cell(60, 10, number_format($registration['amount'], 2), 1, 1, 'R');
$pdf->Ln(10);

// Payment Details
$pdf->Cell(0, 10, 'Payment Details:', 0, 1, 'L');
$pdf->Cell(0, 10, 'Transaction Reference: ' . $registration['password'], 0, 1, 'L');
$pdf->Cell(0, 10, 'Bank Account Number: 0024772709', 0, 1, 'L');
$pdf->Cell(0, 10, 'Account Name: RCCG DTCE PROJECT', 0, 1, 'L');
$pdf->Cell(0, 10, 'Bank Name: UNITY BANK', 0, 1, 'L');
$pdf->Ln(10);

// Thank you note
$pdf->Cell(0, 10, 'Thank you for your payment!', 0, 1, 'C');

// Output the PDF with a custom filename based on invoice number format
$invoice_filename = '#AC/' . date('Y') . '/0' . $registration['id'] . '.pdf';
$pdf->Output($invoice_filename, 'D');

// Prepare and execute the query to save invoice details
$invoice_date = date('Y-m-d H:i:s');
$stmt = $conn->prepare("INSERT INTO invoice (registration_id, invoice_number, name, email, phone_number, password, region, province, p1, p2, p3, amount, date, year, status, created_at) VALUES (:registration_id, :invoice_number, :name, :email, :phone_number, :password, :region, :province, :p1, :p2, :p3, :amount, :date, :year, 'UNPAID', :created_at)");
$stmt->bindParam(':registration_id', $registration_id, PDO::PARAM_INT);
$stmt->bindParam(':invoice_number', $invoice_number);
$stmt->bindParam(':name', $registration['name']);
$stmt->bindParam(':email', $registration['email']);
$stmt->bindParam(':phone_number', $registration['phone_number']);
$stmt->bindParam(':password', $registration['password']);
$stmt->bindParam(':region', $registration['region']);
$stmt->bindParam(':province', $registration['province']);
$stmt->bindParam(':p1', $registration['p1']);
$stmt->bindParam(':p2', $registration['p2']);
$stmt->bindParam(':p3', $registration['p3']);
$stmt->bindParam(':amount', $registration['amount']);
$stmt->bindParam(':date', $invoice_date);
$stmt->bindParam(':year', date('Y'));
$stmt->bindParam(':date', $created_at);
$stmt->execute();
?>
